Remove code path of --arc-start-mode=always-start

* Remove callers to SetArcAlwaysStartForTesting(true)
* Change the remaining SetArcAlwaysStartForTesting(false) to
  SetArcAlwaysStartWithoutPlayStoreForTesting()

TEST=out/Cleanup/unit_tests --gtest_filter=ChromeLauncherController*: \
     Arc*:NoteTakingHelperTest*
BUG=b:69960761
[email protected], [email protected]

Change-Id: I0bbb0774c005db62c346fcfd40f57d897ec86877
Reviewed-on: https://chromium-review.googlesource.com/c/1352495
Commit-Queue: Victor Hsieh <[email protected]>
Reviewed-by: Alexander Alekseev <[email protected]>
Reviewed-by: Yusuke Sato <[email protected]>
Reviewed-by: Yury Khmel <[email protected]>
Cr-Commit-Position: refs/heads/master@{#611816}
diff --git a/components/arc/arc_util.h b/components/arc/arc_util.h
index 993d5e67..7d6ec124 100644
--- a/components/arc/arc_util.h
+++ b/components/arc/arc_util.h
@@ -49,10 +49,9 @@
 // Returns true if ARC OptIn ui needs to be shown for testing.
 bool ShouldShowOptInForTesting();
 
-// Enables to always start ARC for testing, by appending the command line flag.
-// If |bool play_store_available| is not set then flag that disables ARC Play
-// Store UI is added.
-void SetArcAlwaysStartForTesting(bool play_store_available);
+// Enables to always start ARC without Play Store for testing, by appending the
+// command line flag.
+void SetArcAlwaysStartWithoutPlayStoreForTesting();
 
 // Returns true if ARC is installed and running ARC kiosk apps on the current
 // device is officially supported.